import 'dart:developer';
import 'dart:io';

import 'package:flutter/services.dart';

import 'hv_result.dart';
import 'hyper_snap_sdk_constants.dart';

/// DocumentSide enum is used to set the side of document
///
/// values - DocumentSide.front, DocumentSide.back
enum DocumentSide { front, back }

extension DocumentSideExtension on DocumentSide {
  String get documentSideString {
    switch (this) {
      case DocumentSide.front:
        return 'FRONT';
      case DocumentSide.back:
        return 'BACK';
      default:
        return 'FRONT';
    }
  }
}

/// DocumentType enum is used to set the type of document
///
/// values - DocumentType.card, DocumentType.a4, DocumentType.passport, DocumentType.other
enum DocumentType { card, a4, passport, other }

extension DocumentTypeExtension on DocumentType {
  String get documentTypeString {
    switch (this) {
      case DocumentType.card:
        return 'CARD';
      case DocumentType.a4:
        return 'A4';
      case DocumentType.passport:
        return 'PASSPORT';
      case DocumentType.other:
        return 'OTHER';
      default:
        return 'CARD';
    }
  }
}

///HVDocsCapture - to set doc capture configurations and to start doc capture

class HVDocsCapture {
  static const MethodChannel _hyperSnapSDKChannel =
      MethodChannel(HyperSnapSDKConstants.hyperSnapChannel);

  /// start() is used to start doc capture and returns parsed result
  ///
  /// params :
  ///       hvDocConfig(optional) : type - HVDocConfig
  ///       onComplete : type - Function(HVResponse?,HVError?)
  /// returns : void
  static start(
      {HVDocConfig? hvDocConfig,
      required Function(HVResponse?, HVError?) onComplete}) async {
    Map resMap = {};
    HVError? hvError;
    HVResponse? hvResponse;
    try {
      resMap = await _hyperSnapSDKChannel
          .invokeMethod(HyperSnapSDKConstants.startDocCapture, {
        HyperSnapSDKConstants.docConfig:
            hvDocConfig?.toMap() ?? HVDocConfig().toMap(),
      });
      Map errorObj = resMap["errorObj"];
      Map resObj = resMap["resultObj"];

      hvError = (errorObj.isEmpty) ? null : HVError.fromMap(errorObj);
      hvResponse = (resObj.isEmpty) ? null : HVResponse.fromMap(resObj);
    } catch (e) {
      log(e.toString());
    }

    onComplete(hvResponse, hvError);
  }

  //----------------------------------------deprecated ---------------------------
  static HVDocConfig _hvDocConfig = HVDocConfig();
  static HVDocCaptureUIStrings _hvDocCaptureUIStrings = HVDocCaptureUIStrings();

  /// _setHVDocConfig() is used to config the doc capture options
  ///
  /// params :
  ///     hvDocConfig : type -  HVDocConfig,
  /// returns :
  ///     void
  static _setHVDocConfig({required HVDocConfig hvDocConfig}) {
    _hvDocConfig = hvDocConfig;
    _hvDocCaptureUIStrings =
        hvDocConfig.hvDocCaptureUIStrings ?? HVDocCaptureUIStrings();
  }

  @Deprecated('use start()')

  /// docsCaptureStart() is used to start docs activity/view in the client's application
  ///
  /// params :
  /// returns :
  ///     Future<Map>, contains the result(HVError and HVResponse) from native hyperSnapSDK document capture functions
  static Future<Map> docsCaptureStart() async {
    Map map = {};
    try {
      map = await _hyperSnapSDKChannel
          .invokeMethod(HyperSnapSDKConstants.startDocCapture, {
        HyperSnapSDKConstants.docConfig: _hvDocConfig.toMap(),
      });
    } catch (e) {
      log(e.toString());
    }
    return map;
  }

  @Deprecated('use start()')

  /// docsCaptureSetOCRAPIDetails() is used to pre-set the endpoint, side of the document, params, headers to make OCR call
  ///     immediately after the document has been captured
  ///
  /// params :
  ///     ocrEndpoint : type - String, value - endpoint URL which will be used to make ocr call
  ///                                               by default, an endpoint to make ocr calls has been assigned
  ///                                                           inside the sdk itself
  ///     documentSide : type - DocumentSide, value - one of [front, back] to specify the side of the document captured
  ///     params : type - Map, value - map/json containing key-value pairs of different fraud/malice checks provided
  ///                                     by Hyperverge.co
  ///     headers : type - Map, value - map/json containing key-value pairs of different headers options provided
  ///                                     by Hyperverge.co
  /// returns :
  ///     void
  static docsCaptureSetOCRAPIDetails(
      String ocrEndpoint, DocumentSide documentSide, Map params, Map headers) {
    _hvDocConfig.hvOCRAPIDetails = HVOCRAPIDetails(
        ocrEndpoint: ocrEndpoint,
        documentSide: documentSide,
        params: params,
        headers: headers);
    _setHVDocConfig(hvDocConfig: _hvDocConfig);
  }

  @Deprecated('use start()')

  /// docsCaptureSetAspectRatio() is used to set the aspect ratio of the document to be captured
  ///
  /// params :
  ///     aspectRatioValue : type - double
  /// returns :
  ///     void
  static docsCaptureSetAspectRatio(double aspectRatioValue) {
    _hvDocConfig.aspectRatioValue = aspectRatioValue;
    _setHVDocConfig(hvDocConfig: _hvDocConfig);
  }

  @Deprecated('use start()')

  /// docsCaptureSetShouldAddPadding() is set to true if the image has to padded
  ///
  /// params :
  ///     aspectRatioValue : type - bool
  /// returns :
  ///     void
  static docsCaptureSetShouldAddPadding(bool shouldSetPadding) {
    _hvDocConfig.shouldSetPadding = shouldSetPadding;
    _setHVDocConfig(hvDocConfig: _hvDocConfig);
  }

  @Deprecated('use start()')

  /// docsCaptureSetDefaultPadding() provides users to set default padding to
  /// document captures
  ///
  /// params :
  ///     defaultPaddingValue : type - Double
  /// returns :
  ///     void
  static docsCaptureSetDefaultPadding(double defaultPaddingValue) {
    if (Platform.isIOS) {
      _hvDocConfig.defaultPaddingValue = defaultPaddingValue;
      _setHVDocConfig(hvDocConfig: _hvDocConfig);
    } else {
      log('docsCaptureSetDefaultPadding() is not supported in this platform');
    }
  }

  @Deprecated('use start()')

  /// docsCaptureSetShouldShowFlashIcon() is set to true if flash icon has to be shown to the user
  ///     in the client's application
  ///
  /// params :
  ///     shouldShowFlashIcon : type - bool
  /// returns :
  ///     void
  static docsCaptureSetShouldShowFlashIcon(bool shouldShowFlashIcon) {
    _hvDocConfig.shouldShowFlashIcon = shouldShowFlashIcon;
    _setHVDocConfig(hvDocConfig: _hvDocConfig);
  }

  @Deprecated('use start()')

  /// docsCaptureSetShouldShowReviewScreen() is set to true if review screen has to be shown to the user
  ///     in the client's application
  ///
  /// params :
  ///     shouldShowReviewScreen : type - bool
  /// returns :
  ///     void
  static docsCaptureSetShouldShowReviewScreen(bool shouldShowReviewScreen) {
    _hvDocConfig.shouldShowReviewScreen = shouldShowReviewScreen;
    _setHVDocConfig(hvDocConfig: _hvDocConfig);
  }

  @Deprecated('use start()')

  /// docsCaptureSetShouldShowInstructionPage() is set to true if instructions page has to be shown to the user
  ///     in the client's application
  ///
  /// params :
  ///     shouldShowInstructionPage : type - bool
  /// returns :
  ///     void
  static docsCaptureSetShouldShowInstructionPage(
      bool shouldShowInstructionPage) {
    _hvDocConfig.shouldShowInstructionPage = shouldShowInstructionPage;
    _setHVDocConfig(hvDocConfig: _hvDocConfig);
  }

  @Deprecated('use start()')

  /// docsCaptureSetDocumentType()  is used to set the type of the document which has to be captured
  ///
  /// params :
  ///     docTypeValue : type - DocumentType, value - one of [card, a4, passport, other]
  ///                                           by default, card type is initialized in sdk
  /// returns :
  ///     void
  static docsCaptureSetDocumentType(DocumentType docTypeValue) {
    _hvDocConfig.docType = docTypeValue;
    _setHVDocConfig(hvDocConfig: _hvDocConfig);
  }

  @Deprecated('use start()')

  /// docsCaptureSetShouldEnableRetries() is used to set whether HyperSnapSDK should handle retries after any doc capture screen
  ///
  /// params :
  ///     shouldHandleRetries : type - bool
  /// returns :
  ///     void
  static docsCaptureSetShouldEnableRetries(bool shouldEnableRetries) {
    _hvDocConfig.shouldEnableRetries = shouldEnableRetries;
    _setHVDocConfig(hvDocConfig: _hvDocConfig);
  }

  @Deprecated('use start()')

  /// docsCaptureSetUIStrings() is used to set custom strings to all customisable text in HyperSnapSDK
  ///
  /// params :
  ///     uiStrings : type - Map, value - map of customisable strings keys and values
  /// returns :
  ///     void
  static docsCaptureSetUIStrings(Map uiStrings) {
    _hvDocCaptureUIStrings = HVDocCaptureUIStrings.fromMap(uiStrings);
    _hvDocConfig.hvDocCaptureUIStrings = _hvDocCaptureUIStrings;
    _setHVDocConfig(hvDocConfig: _hvDocConfig);
  }

  @Deprecated('use start()')

  /// docsCaptureSetShouldShowCloseAlert() is used to either display or hide close alert dialog when the user tries to close any HyperSnapSDK screens
  ///
  /// params :
  ///     shouldShowCloseAlert : type - bool
  /// returns :
  ///     void
  static docsCaptureSetShouldShowCloseAlert(bool shouldShowCloseAlert) {
    _hvDocConfig.shouldShowCloseAlert = shouldShowCloseAlert;
    _setHVDocConfig(hvDocConfig: _hvDocConfig);
  }

  @Deprecated('use start()')

  /// docsCaptureSetCloseAlertDialogTitle() is used to set custom title for the alert dialog that comes up when closing any screen
  ///
  /// params :
  ///     closeAlertDialogTitle : type - String
  /// returns :
  ///     void
  static docsCaptureSetCloseAlertDialogTitle(String closeAlertDialogTitle) {
    _hvDocConfig.closeAlertDialogTitle = closeAlertDialogTitle;
    _setHVDocConfig(hvDocConfig: _hvDocConfig);
  }

  @Deprecated('use start()')

  /// docsCaptureSetCloseAlertDialogDesc() is used to set custom description for the alert dialog that comes up when closing any screen
  ///
  /// params :
  ///     closeAlertDialogDescription : type - String
  /// returns :
  ///     void
  static docsCaptureSetCloseAlertDialogDesc(
      String closeAlertDialogDescription) {
    _hvDocConfig.closeAlertDialogDescription = closeAlertDialogDescription;
    _setHVDocConfig(hvDocConfig: _hvDocConfig);
  }

  @Deprecated('use start()')

  /// docsCaptureSetShowTrustLogos() is used to either show or hide trust logos in HyperSnapSDK screens
  ///
  /// params :
  ///     shouldShowTrustLogos : type - bool
  /// returns :
  ///     void
  static docsCaptureSetShowTrustLogos(bool shouldShowTrustLogos) {
    _hvDocConfig.shouldShowTrustLogos = shouldShowTrustLogos;
    _setHVDocConfig(hvDocConfig: _hvDocConfig);
  }

  @Deprecated('use start()')

  /// docsCaptureSetDocCaptureSubText() is used to set the sub text inside document capture screen
  ///
  /// params :
  ///     subText : type - String
  /// returns :
  ///     void
  static docsCaptureSetDocCaptureSubText(String subText) {
    _hvDocCaptureUIStrings.docCaptureSubText = subText;
    _hvDocConfig.hvDocCaptureUIStrings = _hvDocCaptureUIStrings;
    _setHVDocConfig(hvDocConfig: _hvDocConfig);
  }

  @Deprecated('use start()')

  /// docsCaptureSetDocCaptureDescription() is used to set the description inside document capture screen
  ///
  /// params :
  ///     description : type - String
  /// returns :
  ///     void
  static docsCaptureSetDocCaptureDescription(String description) {
    _hvDocCaptureUIStrings.docCaptureDescription = description;
    _hvDocConfig.hvDocCaptureUIStrings = _hvDocCaptureUIStrings;
    _setHVDocConfig(hvDocConfig: _hvDocConfig);
  }

  @Deprecated('use start()')

  /// docsCaptureSetDocCaptureTitle() is used to set the title inside document capture screen
  ///
  /// params :
  ///     titleText : type - String
  /// returns :
  ///     void
  static docsCaptureSetDocCaptureTitle(String titleText) {
    _hvDocCaptureUIStrings.docCaptureTitle = titleText;
    _hvDocConfig.hvDocCaptureUIStrings = _hvDocCaptureUIStrings;
    _setHVDocConfig(hvDocConfig: _hvDocConfig);
  }

  @Deprecated('use start()')

  /// docsCaptureSetDocCaptureSubTitle() is used to set the sub-title inside document capture screen
  ///
  /// params :
  ///     subTitleText : type - String
  /// returns :
  ///     void
  static docsCaptureSetDocCaptureSubTitle(String subTitleText) {
    _hvDocCaptureUIStrings.docCaptureSubtitle = subTitleText;
    _hvDocConfig.hvDocCaptureUIStrings = _hvDocCaptureUIStrings;
    _setHVDocConfig(hvDocConfig: _hvDocConfig);
  }

  @Deprecated('use start()')

  /// docsCaptureSetDocReviewTitle() is used to set the title inside document review screen
  ///
  /// params :
  ///     docReviewTitle : type - String
  /// returns :
  ///     void
  static docsCaptureSetDocReviewTitle(String docReviewTitle) {
    _hvDocCaptureUIStrings.docReviewTitle = docReviewTitle;
    _hvDocConfig.hvDocCaptureUIStrings = _hvDocCaptureUIStrings;
    _setHVDocConfig(hvDocConfig: _hvDocConfig);
  }

  @Deprecated('use start()')

  /// docsCaptureSetDocReviewSubTitle() is used to set the sub-title inside document review screen
  ///
  /// params :
  ///     docReviewSubTitle : type - String
  /// returns :
  ///     void
  static docsCaptureSetDocReviewSubTitle(String docReviewSubTitle) {
    _hvDocCaptureUIStrings.docReviewSubtitle = docReviewSubTitle;
    _hvDocConfig.hvDocCaptureUIStrings = _hvDocCaptureUIStrings;
    _setHVDocConfig(hvDocConfig: _hvDocConfig);
  }

  @Deprecated('use start()')

  /// docsCaptureSetDocReviewDescription() is used to set the description inside document review screen
  ///
  /// params :
  ///     docReviewDescription : type - String
  /// returns :
  ///     void
  static docsCaptureSetDocReviewDescription(String docReviewDescription) {
    _hvDocCaptureUIStrings.docReviewDescription = docReviewDescription;
    _hvDocConfig.hvDocCaptureUIStrings = _hvDocCaptureUIStrings;
    _setHVDocConfig(hvDocConfig: _hvDocConfig);
  }

  @Deprecated('use start()')

  /// setShouldAutoCapture() is used to enable the auto capture functionality
  ///
  /// params :
  ///     shouldAutoCapture : type - bool
  /// returns :
  ///     void
  static setShouldAutoCapture(bool shouldAutoCapture) {
    _hvDocConfig.shouldAutoCapture = shouldAutoCapture;
    _setHVDocConfig(hvDocConfig: _hvDocConfig);
  }

  @Deprecated('use start()')

  /// setAutoCaptureDuration() is used to set the wait duration for auto capture
  ///
  /// params :
  ///     shouldAutoCapture : type - int
  /// returns :
  ///     void
  static setAutoCaptureDuration(int duration) {
    _hvDocConfig.autoCaptureDuration = duration;
    _setHVDocConfig(hvDocConfig: _hvDocConfig);
  }
}

/// HVDocConfig - used to configure the doc capture options for the sdk
class HVDocConfig {
  double? aspectRatioValue;
  bool? shouldSetPadding;
  double? defaultPaddingValue;
  bool? shouldShowFlashIcon;
  bool? shouldShowReviewScreen;
  bool? shouldShowInstructionPage;
  DocumentType? docType;
  bool? shouldEnableRetries;
  bool? shouldShowCloseAlert;
  String? closeAlertDialogTitle;
  String? closeAlertDialogDescription;
  bool? shouldShowTrustLogos;
  bool? shouldAutoCapture;
  int? autoCaptureDuration;
  HVOCRAPIDetails? hvOCRAPIDetails;
  HVDocCaptureUIStrings? hvDocCaptureUIStrings;

  /// HVDocConfig() constructor used to configure the doc capture options for the sdk
  ///
  /// params :
  ///     aspectRatioValue(optional) : aspect ratio of the document to be captured, type - double
  ///     shouldSetPadding(optional) : set to true if the image has to padded, type - bool
  ///     defaultPaddingValue(optional) : provides users to set default padding to document captures, type - double
  ///     shouldShowFlashIcon(optional) : set to true if flash icon has to be shown to the user, type - bool
  ///     shouldShowReviewScreen(optional) : set to true if review screen has to be shown to the user, type - bool
  ///     docType(optional) : used to set the type of the document which has to be captured, type - DocumentType
  ///     shouldShowInstructionPage(optional) : set to true if instructions page has to be shown to the user, type - bool
  ///     shouldEnableRetries(optional) : used to set whether HyperSnapSDK should handle retries after any doc capture screen, type - bool
  ///     shouldShowCloseAlert(optional) : used to either display or hide close alert dialog when the user tries to close any HyperSnapSDK screens, type - bool
  ///     closeAlertDialogTitle(optional) : used to set custom title for the alert dialog that comes up when closing any screen, type - String
  ///     closeAlertDialogDescription(optional) : used to set custom description for the alert dialog that comes up when closing any screen, type - String
  ///     shouldShowTrustLogos(optional) : used to either show or hide trust logos in HyperSnapSDK screens, type - bool
  ///     hvOCRAPIDetails(optional) : used to set ocr api details, type - HVOCRAPIDetails
  ///     hvDocCaptureUIStrings(optional) : used to set doc capture ui strings, type - HVDocCaptureUIStrings
  ///     shouldAutoCapture(optional) : used to enable the auto capture functionality, type - bool
  ///     setAutoCaptureDuration(optional) : used to set the wait duration for auto capture, type - int
  HVDocConfig(
      {this.aspectRatioValue,
      this.shouldSetPadding,
      this.defaultPaddingValue,
      this.shouldShowFlashIcon,
      this.shouldShowReviewScreen,
      this.docType,
      this.shouldShowInstructionPage,
      this.shouldEnableRetries,
      this.shouldShowCloseAlert,
      this.closeAlertDialogTitle,
      this.closeAlertDialogDescription,
      this.shouldShowTrustLogos,
      this.hvOCRAPIDetails,
      this.hvDocCaptureUIStrings,
      this.shouldAutoCapture,
      this.autoCaptureDuration});

  Map<String, dynamic> toMap() {
    return {
      HyperSnapSDKConstants.docAspectRatioValue: aspectRatioValue,
      HyperSnapSDKConstants.docShouldSetPadding: shouldSetPadding,
      HyperSnapSDKConstants.docDefaultPaddingValue: defaultPaddingValue,
      HyperSnapSDKConstants.docShouldShowFlashIcon: shouldShowFlashIcon,
      HyperSnapSDKConstants.docShouldShowReviewScreen: shouldShowReviewScreen,
      HyperSnapSDKConstants.docTypeValue: docType?.documentTypeString,
      HyperSnapSDKConstants.docShouldShowInstructionPage:
          shouldShowInstructionPage,
      HyperSnapSDKConstants.docShouldEnableRetries: shouldEnableRetries,
      HyperSnapSDKConstants.docShouldShowCloseAlert: shouldShowCloseAlert,
      HyperSnapSDKConstants.docCloseAlertDialogTitle: closeAlertDialogTitle,
      HyperSnapSDKConstants.docCloseAlertDialogDescription:
          closeAlertDialogDescription,
      HyperSnapSDKConstants.docShouldShowTrustLogos: shouldShowTrustLogos,
      HyperSnapSDKConstants.docAutoCapture: shouldAutoCapture,
      HyperSnapSDKConstants.docAutoCaptureDuration: autoCaptureDuration,
      HyperSnapSDKConstants.ocrApiDetails: hvOCRAPIDetails?.toMap(),
      HyperSnapSDKConstants.docCaptureUIStrings: hvDocCaptureUIStrings?.toMap(),
    };
  }
}

/// HVOCRAPIDetails() -  used to set OCR API Details,
class HVOCRAPIDetails {
  String ocrEndpoint;
  DocumentSide documentSide;
  Map? params;
  Map? headers;

  /// HVOCRAPIDetails() is used to pre-set the endpoint, side of the document, params, headers to make OCR call
  ///     immediately after the document has been captured
  ///
  /// params :
  ///     ocrEndpoint : type - String, value - endpoint URL which will be used to make ocr call
  ///                                               by default, an endpoint to make ocr calls has been assigned
  ///                                                           inside the sdk itself
  ///     documentSide : type - DocumentSide, value - one of [FRONT, BACK] to specify the side of the document captured
  ///     params(optional) : type - Map, value - map/json containing key-value pairs of different fraud/malice checks provided
  ///                                     by Hyperverge.co
  ///     headers(optional) : type - Map, value - map/json containing key-value pairs of different headers options provided
  ///                                     by Hyperverge.co
  HVOCRAPIDetails({
    required this.ocrEndpoint,
    required this.documentSide,
    this.params,
    this.headers,
  });

  /// Convert OCRAPIDetails object to Map
  Map<String, dynamic> toMap() {
    return {
      HyperSnapSDKConstants.ocrEndpoint: ocrEndpoint,
      HyperSnapSDKConstants.documentSideString: documentSide.documentSideString,
      HyperSnapSDKConstants.params: params,
      HyperSnapSDKConstants.headers: headers,
    };
  }
}

/// HVDocCaptureUIStrings - is used to set custom strings to all customisable text in HyperSnapSDK doc capture
class HVDocCaptureUIStrings {
  String? docInstructionsTitle;
  String? docInstructions1;
  String? docInstructions2;
  String? docInstructions3;
  String? docInstructionsProceed;
  String? docCaptureTitle;
  String? docCaptureSubtitle;
  String? docCaptureDescription;
  String? docCaptureSubText;
  String? docReviewRetakeButton;
  String? docReviewContinueButton;
  String? docReviewTitle;
  String? docReviewSubtitle;
  String? docReviewDescription;
  String? docLoaderTitle;
  String? docLoaderDesc;
  String? docRetakeTitleText;
  String? docRetakeButtonText;

  /// HVDocCaptureUIStrings() is used to set custom strings to all customisable text in HyperSnapSDK doc capture

  HVDocCaptureUIStrings({
    this.docInstructionsTitle,
    this.docInstructions1,
    this.docInstructions2,
    this.docInstructions3,
    this.docInstructionsProceed,
    this.docCaptureTitle,
    this.docCaptureSubtitle,
    this.docCaptureDescription,
    this.docCaptureSubText,
    this.docReviewDescription,
    this.docReviewRetakeButton,
    this.docReviewTitle,
    this.docReviewSubtitle,
    this.docLoaderTitle,
    this.docLoaderDesc,
    this.docRetakeTitleText,
    this.docRetakeButtonText,
    this.docReviewContinueButton,
  });

  /// Convert doc capture ui strings object to Map
  Map<String, dynamic> toMap() {
    return {
      HyperSnapSDKConstants.docInstructionsTitle: docInstructionsTitle,
      HyperSnapSDKConstants.docInstructions1: docInstructions1,
      HyperSnapSDKConstants.docInstructions2: docInstructions2,
      HyperSnapSDKConstants.docInstructions3: docInstructions3,
      HyperSnapSDKConstants.docInstructionsProceed: docInstructionsProceed,
      HyperSnapSDKConstants.docCaptureTitle: docCaptureTitle,
      HyperSnapSDKConstants.docCaptureSubtitle: docCaptureSubtitle,
      HyperSnapSDKConstants.docCaptureDescription: docCaptureDescription,
      HyperSnapSDKConstants.docCaptureSubText: docCaptureSubText,
      HyperSnapSDKConstants.docReviewRetakeButton: docReviewRetakeButton,
      HyperSnapSDKConstants.docReviewContinueButton: docReviewContinueButton,
      HyperSnapSDKConstants.docReviewTitle: docReviewTitle,
      HyperSnapSDKConstants.docReviewSubtitle: docReviewSubtitle,
      HyperSnapSDKConstants.docReviewDescription: docReviewDescription,
      HyperSnapSDKConstants.docLoaderTitle: docLoaderTitle,
      HyperSnapSDKConstants.docLoaderDesc: docLoaderDesc,
      HyperSnapSDKConstants.docRetakeTitleText: docRetakeTitleText,
      HyperSnapSDKConstants.docRetakeButtonText: docRetakeButtonText,
    };
  }

  static HVDocCaptureUIStrings fromMap(Map uiStrings) {
    return HVDocCaptureUIStrings(
        docInstructions1: uiStrings["docInstructions1"],
        docReviewTitle: uiStrings["docReviewTitle"],
        docInstructionsProceed: uiStrings["docInstructionsProceed"],
        docReviewDescription: uiStrings["docReviewDescription"],
        docCaptureDescription: uiStrings["docCaptureDescription"],
        docCaptureSubText: uiStrings["docCaptureSubText"],
        docCaptureSubtitle: uiStrings["docCaptureSubtitle"],
        docCaptureTitle: uiStrings["docCaptureTitle"],
        docInstructions2: uiStrings["docInstructions2"],
        docInstructions3: uiStrings["docInstructions3"],
        docInstructionsTitle: uiStrings["docInstructionsTitle"],
        docLoaderDesc: uiStrings["docLoaderDesc"],
        docLoaderTitle: uiStrings["docLoaderTitle"],
        docRetakeButtonText: uiStrings["docRetakeButtonText"],
        docRetakeTitleText: uiStrings["docRetakeTitleText"],
        docReviewContinueButton: uiStrings["docReviewContinueButton"],
        docReviewRetakeButton: uiStrings["docReviewRetakeButton"],
        docReviewSubtitle: uiStrings["docReviewSubtitle"]);
  }
}
