import 'dart:developer';

import 'package:flutter/services.dart';

import 'hv_result.dart';
import 'hyper_snap_sdk_constants.dart';

/// LivenessValue enum is used to set the Liveness string
///
/// values - LivenessValue.none,LivenessValue.textureLiveness
enum LivenessValue { none, textureLiveness }

extension LivenessValueExtension on LivenessValue {
  String get livenessValueString {
    switch (this) {
      case LivenessValue.none:
        return 'NONE';
      case LivenessValue.textureLiveness:
        return 'TEXTURELIVENESS';
      default:
        return 'TEXTURELIVENESS';
    }
  }
}

///HVFaceCapture - to set face capture configurations and to start face capture
class HVFaceCapture {
  static const MethodChannel _hyperSnapSDKChannel =
      MethodChannel(HyperSnapSDKConstants.hyperSnapChannel);

  /// start() is used to start face capture and returns parsed result
  ///
  /// params :
  ///       hvFaceConfig(optional) : type -  HVFaceConfig,
  ///       onComplete : type - Function(HVResponse?,HVError?)
  /// returns : void
  static start(
      {HVFaceConfig? hvFaceConfig,
      required Function(HVResponse?, HVError?) onComplete}) async {
    Map resMap = {};
    HVError? hvError;
    HVResponse? hvResponse;

    try {
      resMap = await _hyperSnapSDKChannel
          .invokeMethod(HyperSnapSDKConstants.startFaceCapture, {
        HyperSnapSDKConstants.faceConfig:
            hvFaceConfig?.toMap() ?? HVFaceConfig().toMap(),
      });

      Map errorObj = resMap["errorObj"];
      Map resObj = resMap["resultObj"];
      hvError = (errorObj.isEmpty) ? null : HVError.fromMap(errorObj);
      hvResponse = (resObj.isEmpty) ? null : HVResponse.fromMap(resObj);
    } catch (e) {
      log(e.toString());
    }
    onComplete(hvResponse, hvError);
  }

  //--------------------------------------------deprecated------------------------------------
  static HVFaceConfig _hvFaceConfig = HVFaceConfig();
  static HVFaceCaptureUIStrings _hvFaceCaptureUIStrings =
      HVFaceCaptureUIStrings();
  static HVLivenessAPIDetails _hvLivenessAPIDetails =
      HVLivenessAPIDetails(livenessEndpoint: "");

  /// setHVFaceConfig() is used to config the face capture options
  ///
  /// params :
  ///     hvFaceConfig : type -  HVFaceConfig,
  /// returns :
  ///     void
  static _setHVFaceConfig({required HVFaceConfig hvFaceConfig}) {
    _hvFaceConfig = hvFaceConfig;
    _hvFaceCaptureUIStrings =
        hvFaceConfig.hvFaceCaptureUIStrings ?? HVFaceCaptureUIStrings();
    _hvLivenessAPIDetails = hvFaceConfig.hvLivenessAPIDetails ??
        HVLivenessAPIDetails(livenessEndpoint: "");
    //handling if liveness end point is given
    if (_hvLivenessAPIDetails.livenessEndpoint.isEmpty) {
      _hvFaceConfig.hvLivenessAPIDetails = null;
    }
  }

  @Deprecated('use start()')

  /// faceCaptureStart() is used to start face activity/view in the client's application
  ///
  /// params :
  /// returns :
  ///     Future<Map>, contains the result(HVError and HVResponse) from native hypersnapSDK face capture functions
  static Future<Map> faceCaptureStart() async {
    Map map = {};
    try {
      map = await _hyperSnapSDKChannel
          .invokeMethod(HyperSnapSDKConstants.startFaceCapture, {
        HyperSnapSDKConstants.faceConfig: _hvFaceConfig.toMap(),
      });
    } catch (e) {
      log(e.toString());
    }
    return map;
  }

  @Deprecated('use start()')

  /// faceCaptureSetShouldReturnFullImageUrl() is set to true if full image Uri has to be sent inside the result from
  ///     face activity along with other parameters
  ///
  /// params :
  ///     shouldReturnFullImageUrl : type - bool
  /// returns :
  ///     void
  static faceCaptureSetShouldReturnFullImageUrl(bool shouldReturnFullImageUrl) {
    _hvFaceConfig.shouldReturnFullImageUrl = shouldReturnFullImageUrl;
    _setHVFaceConfig(hvFaceConfig: _hvFaceConfig);
  }

  @Deprecated('use start()')

  /// faceCaptureSetShouldShowCameraSwitchButton() is set to true if camera switch button has to be shown to the user
  ///     in the client's application
  ///
  /// params :
  ///     shouldShow : type - bool
  /// returns :
  ///     void
  static faceCaptureSetShouldShowCameraSwitchButton(bool shouldShow) {
    _hvFaceConfig.shouldShowCameraSwitchButton = shouldShow;
    _setHVFaceConfig(hvFaceConfig: _hvFaceConfig);
  }

  @Deprecated('use start()')

  /// faceCaptureSetShouldShowInstructionPage() is set to true if instructions page has to be shown to the user
  ///     in the client's application
  ///
  /// params :
  ///     shouldShowInstructionPage : type - bool
  /// returns :
  ///     void
  static faceCaptureSetShouldShowInstructionPage(
      bool shouldShowInstructionPage) {
    _hvFaceConfig.shouldShowInstructionPage = shouldShowInstructionPage;
    _setHVFaceConfig(hvFaceConfig: _hvFaceConfig);
  }

  @Deprecated('use start()')
  static faceCaptureSetAutoCapture(
    bool shouldAutoCapture, {
    int autoCaptureDuration = 1500,
  }) {
    _hvFaceConfig.enableAutoCapture = shouldAutoCapture;
    _hvFaceConfig.autoCaptureDuration = autoCaptureDuration;
    _setHVFaceConfig(hvFaceConfig: _hvFaceConfig);
  }

  @Deprecated('use start()')

  /// faceCaptureSetShouldUseBackCamera() is set to true if the face capture screen should start with back camera
  ///     rather than default front camera
  ///
  /// params :
  ///     shouldUseBackCamera : type - bool
  /// returns :
  ///     void
  static faceCaptureSetShouldUseBackCamera(bool shouldUseBackCamera) {
    _hvFaceConfig.shouldUseBackCamera = shouldUseBackCamera;
    _setHVFaceConfig(hvFaceConfig: _hvFaceConfig);
  }

  @Deprecated('use start()')

  /// faceCaptureSetShouldAddPadding() is set to true if the image has to padded
  ///
  /// params :
  ///     shouldSetPadding : type - bool
  /// returns :
  ///     void
  static faceCaptureSetShouldAddPadding(bool shouldSetPadding) {
    _hvFaceConfig.shouldAddPadding = shouldSetPadding;
    _setHVFaceConfig(hvFaceConfig: _hvFaceConfig);
  }

  @Deprecated('use start()')

  /// faceCaptureSetShouldHandleRetries() is used to set whether HyperSnapSDK should handle retries after any face capture screen
  ///
  /// params :
  ///     shouldHandleRetries : type - bool
  /// returns :
  ///     void
  static faceCaptureSetShouldHandleRetries(bool shouldHandleRetries) {
    _hvFaceConfig.shouldHandleRetries = shouldHandleRetries;
    _setHVFaceConfig(hvFaceConfig: _hvFaceConfig);
  }

  @Deprecated('use start()')

  /// faceCaptureSetShouldShowCloseAlert() is used to either display or hide close alert dialog when the user tries to close any HyperSnapSDK screens
  ///
  /// params :
  ///     shouldShowCloseAlert : type - bool
  /// returns :
  ///     void
  static faceCaptureSetShouldShowCloseAlert(bool shouldShowCloseAlert) {
    _hvFaceConfig.shouldShowCloseAlert = shouldShowCloseAlert;
    _setHVFaceConfig(hvFaceConfig: _hvFaceConfig);
  }

  @Deprecated('use start()')

  /// faceCaptureSetCloseAlertDialogTitle() is used to set custom title for the alert dialog that comes up when closing any screen
  ///
  /// params :
  ///     closeAlertDialogTitle : type - String
  /// returns :
  ///     void
  static faceCaptureSetCloseAlertDialogTitle(String closeAlertDialogTitle) {
    _hvFaceConfig.closeAlertDialogTitle = closeAlertDialogTitle;
    _setHVFaceConfig(hvFaceConfig: _hvFaceConfig);
  }

  @Deprecated('use start()')

  /// faceCaptureSetCloseAlertDialogDesc() is used to set custom description for the alert dialog that comes up when closing any screen
  ///
  /// params :
  ///     closeAlertDialogDescription : type - String
  /// returns :
  ///     void
  static faceCaptureSetCloseAlertDialogDesc(
      String closeAlertDialogDescription) {
    _hvFaceConfig.closeAlertDialogDescription = closeAlertDialogDescription;
    _setHVFaceConfig(hvFaceConfig: _hvFaceConfig);
  }

  @Deprecated('use start()')

  /// faceCaptureSetShowTrustLogos() is used to either show or hide trust logos in HyperSnapSDK screens
  ///
  /// params :
  ///     shouldShowTrustLogos : type - bool
  /// returns :
  ///     void
  static faceCaptureSetShowTrustLogos(bool shouldShowTrustLogos) {
    _hvFaceConfig.shouldShowTrustLogos = shouldShowTrustLogos;
    _setHVFaceConfig(hvFaceConfig: _hvFaceConfig);
  }

  @Deprecated('use start()')

  /// faceCaptureSetUIStrings() is used to set custom strings to all customisable text in HyperSnapSDK
  ///
  /// params :
  ///     uiStrings : type - Map, value - map of customisable strings keys and values
  /// returns :
  ///     void
  static faceCaptureSetUIStrings(Map uiStrings) {
    _hvFaceConfig.hvFaceCaptureUIStrings =
        HVFaceCaptureUIStrings.fromMap(uiStrings);
    _setHVFaceConfig(hvFaceConfig: _hvFaceConfig);
  }

  @Deprecated('use start()')

  /// faceCaptureSetFaceCaptureTitle() is used to set the title inside face capture screen
  ///
  /// params :
  ///     faceCaptureTitle : type - String
  /// returns :
  ///     void
  static faceCaptureSetFaceCaptureTitle(String faceCaptureTitle) {
    _hvFaceCaptureUIStrings.faceCaptureTitle = faceCaptureTitle;
    _hvFaceConfig.hvFaceCaptureUIStrings = _hvFaceCaptureUIStrings;
    _setHVFaceConfig(hvFaceConfig: _hvFaceConfig);
  }

  @Deprecated('use start()')

  /// faceCaptureSetFaceCaptureSubTitle() is used to set the sub-title inside face capture screen
  ///
  /// params :
  ///     faceCaptureSubTitle : type - String
  /// returns :
  ///     void
  static faceCaptureSetFaceCaptureSubTitle(String faceCaptureSubTitle) {
    _hvFaceCaptureUIStrings.faceCaptureSubtitle = faceCaptureSubTitle;
    _hvFaceConfig.hvFaceCaptureUIStrings = _hvFaceCaptureUIStrings;
    _setHVFaceConfig(hvFaceConfig: _hvFaceConfig);
  }

  @Deprecated('use start()')

  /// faceCaptureSetLivenessEndpoint() is used to overwrite the default liveness endpoint
  ///
  /// params :
  ///     livenessEndpoint : type - String, value - endpoint URL which will be used to make liveness call
  ///                                               by default, an endpoint to make liveness calls has been assigned
  ///                                                           inside the sdk itself
  /// returns :
  ///     void
  static faceCaptureSetLivenessEndpoint(String livenessEndpoint) {
    _hvLivenessAPIDetails.livenessEndpoint = livenessEndpoint;
    _hvFaceConfig.hvLivenessAPIDetails = _hvLivenessAPIDetails;
    _setHVFaceConfig(hvFaceConfig: _hvFaceConfig);
  }

  @Deprecated('use start()')

  /// faceCaptureSetLivenessAPIParameters() is used to set liveness api parameters which will be used to make liveness call
  ///
  /// params :
  ///     params : type - Map, value - Map containing key-value pairs of different fraud/malice checks provided
  ///                                     by Hyperverge.co
  /// returns :
  ///     void
  static faceCaptureSetLivenessAPIParameters(Map params) {
    _hvLivenessAPIDetails.params = params;
    _hvFaceConfig.hvLivenessAPIDetails = _hvLivenessAPIDetails;
    _setHVFaceConfig(hvFaceConfig: _hvFaceConfig);
  }

  @Deprecated('use start()')

  /// faceCaptureSetLivenessAPIHeaders() is used to set liveness api headers which will be used to make liveness call
  ///
  /// params :
  ///     headers : type - Map, value - Map containing key-value pairs of different headers options provided
  ///                                     by Hyperverge.co
  /// returns :
  ///     void
  static faceCaptureSetLivenessAPIHeaders(Map headers) {
    _hvLivenessAPIDetails.headers = headers;
    _hvFaceConfig.hvLivenessAPIDetails = _hvLivenessAPIDetails;
    _setHVFaceConfig(hvFaceConfig: _hvFaceConfig);
  }

  @Deprecated('use start()')

  /// faceCaptureSetLivenessMode() is used to overwrite the default Liveness Mode
  ///
  /// params :
  ///     livenessValue : type - LivenessValue, value - one of [none, textureLiveness], by default, TEXTURELIVENESS is
  ///                                             set inside the sdk itself
  /// returns :
  ///     void
  static faceCaptureSetLivenessMode(LivenessValue livenessValue) {
    _hvLivenessAPIDetails.livenessValue = livenessValue;
    _hvFaceConfig.hvLivenessAPIDetails = _hvLivenessAPIDetails;
    _setHVFaceConfig(hvFaceConfig: _hvFaceConfig);
  }

  @Deprecated('use start()')

  /// faceCaptureSetPadding() is used to set specific amount of padding in all four directions to the image
  ///
  /// params :
  ///     leftPadding : type - double
  ///     rightPadding : type - double
  ///     topPadding : type - double
  ///     bottomPadding : type - double
  /// returns :
  ///     void
  static faceCaptureSetPadding(double leftPadding, double rightPadding,
      double topPadding, double bottomPadding) {
    _hvFaceConfig.padding = HVFaceCapturePadding(
        left: leftPadding,
        right: rightPadding,
        top: topPadding,
        bottom: bottomPadding);
    _setHVFaceConfig(hvFaceConfig: _hvFaceConfig);
  }

  @Deprecated('use start()')

  /// faceCaptureSetShouldRecordVideo() is set to true if user's selfie flow has to be recorded
  /// (currently supporting video recording only for Android platform)
  /// params :
  ///     shouldRecordVideo : type - bool
  ///     numberOfFrames : The last {numberOfFrames} which has to be recorded (default : 200 frames)
  ///     bitrateM : bitrate (in million -> M) of the recorded video (default : 3M bitrate)
  ///     fps : FPS at which video has to recorded (default : 30 fps)
  /// returns :
  ///     void
  static faceCaptureSetVideoRecording(bool shouldRecordVideo,
      {int numberOfFrames = 50, double bitrateM = 1, int fps = 30}) {
    _hvFaceConfig.videoRecordingConfig = HVVideoRecordingConfig(
        shouldRecordVideo: shouldRecordVideo,
        noOfFrames: numberOfFrames,
        bitRateM: bitrateM,
        fps: fps);
    _setHVFaceConfig(hvFaceConfig: _hvFaceConfig);
  }

  @Deprecated('use start()')

  /// setShouldCheckActiveLiveness() is used to check for active liveness
  ///
  /// params :
  ///     shouldCheckActiveLiveness : type - bool
  /// returns :
  ///     void
  static setShouldCheckActiveLiveness(bool shouldCheckActiveLiveness) {
    _hvFaceConfig.shouldCheckActiveLiveness = shouldCheckActiveLiveness;
    _setHVFaceConfig(hvFaceConfig: _hvFaceConfig);
  }

  @Deprecated('use start()')

  /// setTotalGestures() is used to customize the number of gestures when checking active liveness
  ///
  /// params :
  ///     totalGestures : type - int
  /// returns :
  ///     void
  static setTotalGestures(int totalGestures) {
    _hvFaceConfig.totalGestures = totalGestures;
    _setHVFaceConfig(hvFaceConfig: _hvFaceConfig);
  }
}

/// HVFaceConfig - used to configure the face capture options for the sdk
class HVFaceConfig {
  HVVideoRecordingConfig? videoRecordingConfig;
  HVFaceCapturePadding? padding;
  bool? shouldShowCameraSwitchButton;
  bool? shouldReturnFullImageUrl;
  bool? shouldUseBackCamera;
  bool? shouldAddPadding;
  bool? enableAutoCapture;
  int? autoCaptureDuration;
  bool? shouldShowInstructionPage;
  bool? shouldHandleRetries;
  bool? shouldShowCloseAlert;
  String? closeAlertDialogTitle;
  String? closeAlertDialogDescription;
  bool? shouldShowTrustLogos;
  bool? shouldCheckActiveLiveness;
  int? totalGestures;
  HVLivenessAPIDetails? hvLivenessAPIDetails;
  HVFaceCaptureUIStrings? hvFaceCaptureUIStrings;

  /// HVFaceConfig() constructor used to configure the face capture options for the sdk
  ///
  /// params :
  ///     videoRecordingConfig(optional) : to config th video recording , type - HVVideoRecordingConfig
  ///     padding(optional) : is used to set specific amount of padding in all four directions to the image , type - HVFaceCapturePadding
  ///     shouldShowCameraSwitchButton(optional) : is set to true if camera switch button has to be shown to the user, type - bool
  ///     shouldReturnFullImageUrl(optional) : is set to true if full image Uri has to be sent inside the result from face activity along with other parameters, type - bool
  ///     shouldUseBackCamera(optional) : is set to true if the face capture screen should start with back camera, type - bool
  ///     shouldAddPadding(optional) : is set to true if the image has to padded, type - bool
  ///     enableAutoCapture(optional) : set to true if selfie has to be captured automatically, type - bool
  ///     autoCaptureDuration(optional) : used to set the wait duration for auto capture, type - int
  ///     shouldShowInstructionPage(optional) : set to true if instructions page has to be shown to the user, type - bool
  ///     shouldHandleRetries(optional) : used to set whether HyperSnapSDK should handle retries after any face capture screen, type - bool
  ///     shouldShowCloseAlert(optional) : used to either display or hide close alert dialog when the user tries to close any HyperSnapSDK screens, type - bool
  ///     closeAlertDialogTitle(optional) : used to set custom title for the alert dialog that comes up when closing any screen, type - String
  ///     closeAlertDialogDescription(optional) :  used to set custom description for the alert dialog that comes up when closing any screen, type - String
  ///     shouldShowTrustLogos(optional) : used to either show or hide trust logos in HyperSnapSDK screens, type - bool
  ///     hvLivenessAPIDetails(optional) : used to set liveness api details, type - HVLivenessAPIDetails
  ///     hvFaceCaptureUIStrings(optional) : used to set face capture ui strings, type - HVFaceCaptureUIStrings
  ///     shouldCheckActiveLiveness(optional) : used to check for active liveness, type - bool
  ///     setTotalGestures(optional) : used to customize the number of gestures when checking active liveness, type - int

  HVFaceConfig(
      {this.videoRecordingConfig,
      this.padding,
      this.shouldShowCameraSwitchButton,
      this.shouldReturnFullImageUrl,
      this.shouldUseBackCamera,
      this.shouldShowInstructionPage,
      this.shouldHandleRetries,
      this.shouldShowCloseAlert,
      this.closeAlertDialogTitle,
      this.closeAlertDialogDescription,
      this.shouldShowTrustLogos,
      this.hvLivenessAPIDetails,
      this.hvFaceCaptureUIStrings,
      this.enableAutoCapture,
      this.shouldAddPadding,
      this.autoCaptureDuration,
      this.shouldCheckActiveLiveness,
      this.totalGestures});

  Map<String, dynamic> toMap() {
    return {
      HyperSnapSDKConstants.faceShouldShowInstructionPage:
          shouldShowInstructionPage,
      HyperSnapSDKConstants.faceShouldHandleRetries: shouldHandleRetries,
      HyperSnapSDKConstants.faceShouldShowCloseAlert: shouldShowCloseAlert,
      HyperSnapSDKConstants.faceCloseAlertDialogTitle: closeAlertDialogTitle,
      HyperSnapSDKConstants.faceCloseAlertDialogDesc:
          closeAlertDialogDescription,
      HyperSnapSDKConstants.faceShouldShowTrustLogos: shouldShowTrustLogos,
      HyperSnapSDKConstants.livenessApiDetails: hvLivenessAPIDetails?.toMap(),
      HyperSnapSDKConstants.faceCaptureUIStrings:
          hvFaceCaptureUIStrings?.toMap(),
      HyperSnapSDKConstants.faceVideoRecording: videoRecordingConfig?.toMap(),
      HyperSnapSDKConstants.facePadding: padding?.toMap(),
      HyperSnapSDKConstants.faceShouldShowCameraSwitchButton:
          shouldShowCameraSwitchButton,
      HyperSnapSDKConstants.faceShouldReturnFullImageUrl:
          shouldReturnFullImageUrl,
      HyperSnapSDKConstants.faceShouldUseBackCamera: shouldUseBackCamera,
      HyperSnapSDKConstants.faceAutoCapture: enableAutoCapture,
      HyperSnapSDKConstants.checkActiveLiveness: shouldCheckActiveLiveness,
      HyperSnapSDKConstants.totalGestures: totalGestures,
      HyperSnapSDKConstants.autoCaptureDuration: autoCaptureDuration,
    };
  }
}

/// HVLivenessAPIDetails - used to pre-set the liveness endpoint details,
class HVLivenessAPIDetails {
  String livenessEndpoint;
  LivenessValue? livenessValue;
  Map? params;
  Map? headers;

  /// HVLivenessAPIDetails() is used to pre-set the endpoint, liveness value, params, headers to make liveness api call
  ///     immediately after the document has been captured
  ///
  /// params :
  ///     livenessEndpoint : type - String, value - endpoint URL which will be used to make liveness call
  ///                                               by default, an endpoint to make liveness calls has been assigned
  ///                                                           inside the sdk itself
  ///     livenessValue(optional) : type - LivenessValue, value - one of [none,textureLiveness ] to specify the side of the document captured
  ///     params(optional) : type - Map, value - map/json containing key-value pairs of different fraud/malice checks provided
  ///                                     by Hyperverge.co
  ///     headers(optional) : type - Map, value - map/json containing key-value pairs of different headers options provided
  ///                                     by Hyperverge.co
  HVLivenessAPIDetails({
    required this.livenessEndpoint,
    this.livenessValue,
    this.params,
    this.headers,
  });

  /// Convert OCRAPIDetails object to Map
  Map<String, dynamic> toMap() {
    return {
      HyperSnapSDKConstants.livenessEndpoint: livenessEndpoint,
      HyperSnapSDKConstants.livenessValue: livenessValue?.livenessValueString,
      HyperSnapSDKConstants.livenessParams: params,
      HyperSnapSDKConstants.livenessHeaders: headers,
    };
  }
}

/// HVFaceCaptureUIStrings - used to set custom strings to all customisable text in HyperSnapSDK face capture
class HVFaceCaptureUIStrings {
  String? faceInstructionsTitle;
  String? faceInstructionsDesc;
  String? faceInstructionsTop1;
  String? faceInstructionsTop2;
  String? faceInstructionsNoGlasses;
  String? faceInstructionsBrightLight;
  String? faceInstructionsNoHat;
  String? faceInstructionsProceed;
  String? faceInstructionsProceedBackCam;
  String? faceCaptureTitle;
  String? faceCaptureSubtitle;
  String? faceCaptureMoveCloser;
  String? faceCaptureFaceFound;
  String? faceCaptureFaceNotFound;
  String? faceCaptureMoveAway;
  String? faceCaptureMultipleFaces;
  String? faceCaptureAutoCaptureWait;
  String? faceCaptureAutoCaptureAction;
  String? faceLoaderTitle;
  String? faceLoaderDesc;
  String? faceRetakeTitleText;
  String? faceRetakeButtonText;
  String? faceGestureLookLeft;
  String? faceGestureLookStraight;
  String? faceGestureLookRight;

  /// HVFaceCaptureUIStrings() is used to set custom strings to all customisable text in HyperSnapSDK face capture
  HVFaceCaptureUIStrings(
      {this.faceInstructionsTitle,
      this.faceInstructionsDesc,
      this.faceInstructionsTop1,
      this.faceInstructionsTop2,
      this.faceInstructionsNoGlasses,
      this.faceInstructionsBrightLight,
      this.faceInstructionsNoHat,
      this.faceInstructionsProceed,
      this.faceInstructionsProceedBackCam,
      this.faceCaptureTitle,
      this.faceCaptureSubtitle,
      this.faceCaptureMoveCloser,
      this.faceCaptureFaceFound,
      this.faceCaptureFaceNotFound,
      this.faceCaptureMoveAway,
      this.faceCaptureMultipleFaces,
      this.faceCaptureAutoCaptureWait,
      this.faceCaptureAutoCaptureAction,
      this.faceLoaderDesc,
      this.faceLoaderTitle,
      this.faceRetakeButtonText,
      this.faceRetakeTitleText,
      this.faceGestureLookLeft,
      this.faceGestureLookRight,
      this.faceGestureLookStraight});

  /// Convert doc capture ui strings object to Map
  Map<String, dynamic> toMap() {
    return {
      HyperSnapSDKConstants.faceInstructionsTitle: faceInstructionsTitle,
      HyperSnapSDKConstants.faceInstructionsDesc: faceInstructionsDesc,
      HyperSnapSDKConstants.faceInstructionsTop1: faceInstructionsTop1,
      HyperSnapSDKConstants.faceInstructionsTop2: faceInstructionsTop2,
      HyperSnapSDKConstants.faceInstructionsNoGlasses:
          faceInstructionsNoGlasses,
      HyperSnapSDKConstants.faceInstructionsBrightLight:
          faceInstructionsBrightLight,
      HyperSnapSDKConstants.faceInstructionsNoHat: faceInstructionsNoHat,
      HyperSnapSDKConstants.faceInstructionsProceed: faceInstructionsProceed,
      HyperSnapSDKConstants.faceInstructionsProceedBackCam:
          faceInstructionsProceedBackCam,
      HyperSnapSDKConstants.faceCaptureTitle: faceCaptureTitle,
      HyperSnapSDKConstants.faceCaptureSubtitle: faceCaptureSubtitle,
      HyperSnapSDKConstants.faceCaptureMoveCloser: faceCaptureMoveCloser,
      HyperSnapSDKConstants.faceCaptureFaceFound: faceCaptureFaceFound,
      HyperSnapSDKConstants.faceCaptureFaceNotFound: faceCaptureFaceNotFound,
      HyperSnapSDKConstants.faceCaptureMoveAway: faceCaptureMoveAway,
      HyperSnapSDKConstants.faceCaptureMultipleFaces: faceCaptureMultipleFaces,
      HyperSnapSDKConstants.faceCaptureAutoCaptureWait:
          faceCaptureAutoCaptureWait,
      HyperSnapSDKConstants.faceCaptureAutoCaptureAction:
          faceCaptureAutoCaptureAction,
      HyperSnapSDKConstants.faceLoaderDesc: faceLoaderDesc,
      HyperSnapSDKConstants.faceLoaderTitle: faceLoaderTitle,
      HyperSnapSDKConstants.faceRetakeButtonText: faceRetakeButtonText,
      HyperSnapSDKConstants.faceRetakeTitleText: faceRetakeTitleText,
      HyperSnapSDKConstants.faceGesture_lookLeft: faceGestureLookLeft,
      HyperSnapSDKConstants.faceGesture_lookRight: faceGestureLookRight,
      HyperSnapSDKConstants.faceGesture_lookStraight: faceGestureLookStraight,
    };
  }

  static HVFaceCaptureUIStrings fromMap(Map uiStrings) {
    return HVFaceCaptureUIStrings(
      faceCaptureFaceFound: uiStrings["faceCaptureFaceFound"],
      faceInstructionsTitle: uiStrings["faceInstructionsTitle"],
      faceCaptureAutoCaptureAction: uiStrings["faceCaptureAutoCaptureAction"],
      faceCaptureAutoCaptureWait: uiStrings["faceCaptureAutoCaptureWait"],
      faceCaptureFaceNotFound: uiStrings["faceCaptureFaceNotFound"],
      faceCaptureMoveAway: uiStrings["faceCaptureMoveAway"],
      faceCaptureMoveCloser: uiStrings["faceCaptureMoveCloser"],
      faceCaptureMultipleFaces: uiStrings["faceCaptureMultipleFaces"],
      faceCaptureSubtitle: uiStrings["faceCaptureSubtitle"],
      faceCaptureTitle: uiStrings["faceCaptureTitle"],
      faceInstructionsBrightLight: uiStrings["faceInstructionsBrightLight"],
      faceInstructionsDesc: uiStrings["faceInstructionsDesc"],
      faceInstructionsNoGlasses: uiStrings["faceInstructionsNoGlasses"],
      faceInstructionsNoHat: uiStrings["faceInstructionsNoHat"],
      faceInstructionsProceed: uiStrings["faceInstructionsProceed"],
      faceInstructionsProceedBackCam:
          uiStrings["faceInstructionsProceedBackCam"],
      faceInstructionsTop1: uiStrings["faceInstructionsTop1"],
      faceInstructionsTop2: uiStrings["faceInstructionsTop2"],
      faceLoaderDesc: uiStrings["faceLoaderDesc"],
      faceLoaderTitle: uiStrings["faceLoaderTitle"],
      faceRetakeButtonText: uiStrings["faceRetakeButtonText"],
      faceRetakeTitleText: uiStrings["faceRetakeTitleText"],
      faceGestureLookLeft: uiStrings["faceGesture_lookLeft"],
      faceGestureLookRight: uiStrings["faceGesture_lookRight"],
      faceGestureLookStraight: uiStrings["faceGesture_lookStraight"],
    );
  }
}

/// HVVideoRecordingConfig - used to config user's selfie flow recording
class HVVideoRecordingConfig {
  bool shouldRecordVideo;
  int? noOfFrames;
  double? bitRateM;
  int? fps;

  /// HVVideoRecordingConfig() used to config user's selfie flow recording
  /// (currently supporting video recording only for Android platform)
  /// params :
  ///     shouldRecordVideo : set to true if user's selfie flow has to be recorded ,type - bool
  ///     numberOfFrames : The last {numberOfFrames} which has to be recorded (default : 200 frames) , type - int
  ///     bitrateM : bitrate (in million -> M) of the recorded video (default : 3M bitrate), type - double
  ///     fps : FPS at which video has to recorded (default : 30 fps) type - int
  /// returns :
  ///     void
  HVVideoRecordingConfig(
      {this.bitRateM,
      this.fps,
      this.noOfFrames,
      required this.shouldRecordVideo});

  Map<String, dynamic> toMap() {
    return {
      HyperSnapSDKConstants.noOfFrames: noOfFrames,
      HyperSnapSDKConstants.fps: fps,
      HyperSnapSDKConstants.shouldRecordVideo: shouldRecordVideo,
      HyperSnapSDKConstants.bitRateM: bitRateM
    };
  }
}

/// HVFaceCapturePadding - used to set specific amount of padding in all four directions to the image
class HVFaceCapturePadding {
  double left;
  double right;
  double top;
  double bottom;

  /// HVFaceCapturePadding() is used to set specific amount of padding in all four directions to the image
  ///
  /// params :
  ///     leftPadding : type - double
  ///     rightPadding : type - double
  ///     topPadding : type - double
  ///     bottomPadding : type - double
  /// returns :
  ///     void
  HVFaceCapturePadding(
      {this.left = 0.0, this.right = 0.0, this.top = 0.0, this.bottom = 0.0});

  Map<String, dynamic> toMap() {
    return {
      HyperSnapSDKConstants.paddingLeft: left,
      HyperSnapSDKConstants.paddingRight: right,
      HyperSnapSDKConstants.paddingTop: top,
      HyperSnapSDKConstants.paddingBottom: bottom
    };
  }
}
