import 'dart:developer';
import 'dart:io' show Platform;

import 'package:flutter/services.dart';
import 'package:hypersnapsdk_flutter/hyper_snap_sdk_constants.dart';

/// Region enum is used to set the region
///
/// values - Region.india, Region.asiaPacific, Region.unitedStates, Region.africa
enum Region { india, asiaPacific, unitedStates, africa }

extension RegionExtension on Region {
  String get regionName {
    switch (this) {
      case Region.india:
        return (Platform.isAndroid)?'INDIA':'India';
      case Region.africa:
        return (Platform.isAndroid)?'AFRICA':'Africa';
      case Region.unitedStates:
        return (Platform.isAndroid)?'UNITED_STATES':'UnitedStates';
      case Region.asiaPacific:
        return (Platform.isAndroid)?'ASIA_PACIFIC':'AsiaPacific';
      default:
        return (Platform.isAndroid)?'INDIA':'India';
    }
  }
}

/// HyperSnapSDK - used to initial the sdk,to config the sdk, and to manage user sessions
class HyperSnapSDK {
  static const MethodChannel _hyperSnapSDKChannel =
      MethodChannel(HyperSnapSDKConstants.hyperSnapChannel);

  /// initialize() is used initialize the hypersnapsdk inside the client's application
  ///
  /// params :
  ///     appID : type - String, value - Provided by hyperverge.co
  ///     appKey : type - String, value - Provided by hyperverge.co
  ///     region : type - Region, value - one of [India, APAC, etc]
  /// returns :
  ///     Future<String> `initialised` if initialization is successful

  static Future<String> initialize(
      String appId, String appKey, Region region) async {
    String result = "Not Initialized";
    try {
      result = await _hyperSnapSDKChannel
          .invokeMethod(HyperSnapSDKConstants.initialize, {
        HyperSnapSDKConstants.appId: appId,
        HyperSnapSDKConstants.appKey: appKey,
        HyperSnapSDKConstants.region: region.regionName
      });
    } catch (e) {
      log(e.toString());
    }
    return result;
  }

  /// initializeWithToken() is used to initilalize the hypersnapsdk with accessToken inside the client's application
  ///
  /// params :
  ///     appID : type - String, value - Provided by hyperverge.co
  ///     accessToken : type - String, value - Provided by hyperverge.co
  ///     region : type - Region, value - one of [India, APAC, etc]
  /// returns :
  ///     Future<String> `initialised` if initialization is successful

  static Future<String> initializeWithToken(
      String appId, String accessToken, Region region) async {
    String result = "Not Initialized";

    try {
      result = await _hyperSnapSDKChannel
          .invokeMethod(HyperSnapSDKConstants.initializeWithToken, {
        HyperSnapSDKConstants.appId: appId,
        HyperSnapSDKConstants.accessToken: accessToken,
        HyperSnapSDKConstants.region: region.regionName
      });
    } catch (e) {
      log(e.toString());
    }
    return result;
  }

  /// setHyperSnapSDKConfig is used to config the sdk options
  ///
  /// params :
  ///     hyperSnapSDKOption : type -  HyperSnapSDKOption,
  /// returns :
  ///     void

  static setHyperSnapSDKConfig(
      {required HyperSnapSDKConfig hyperSnapSDKConfig}) async {
    _hyperSnapSDKConfig = hyperSnapSDKConfig;

    try {
      await _hyperSnapSDKChannel.invokeMethod(
          HyperSnapSDKConstants.hyperSnapSDKConfig,
          _hyperSnapSDKConfig.toMap());
    } catch (e) {
      log(e.toString());
    }
  }

  /// startUserSession() is used to start the user session in the application
  ///
  /// params :
  ///     userID : type - String, value - userID which can be generated by the client
  /// returns :
  ///    Future<bool>, returns true if user session has been started successfully
  static Future<bool> startUserSession(String userID) async {
    bool flag = false;
    try {
      flag = await _hyperSnapSDKChannel.invokeMethod(
          HyperSnapSDKConstants.startUserSession,
          {HyperSnapSDKConstants.userId: userID});
    } catch (e) {
      log(e.toString());
    }
    return flag;
  }

  /// endUserSession() is used by the client to end the session if any session is active
  ///
  /// params : empty
  /// returns : void
  static endUserSession() async {
    try {
      await _hyperSnapSDKChannel
          .invokeMethod(HyperSnapSDKConstants.endUserSession);
    } catch (e) {
      log(e.toString());
    }
  }

  /// sortJSONKeysAlphabetically() is used to sort the keys of the response object alphabetically so that signature checks
  /// and other related checks can be performed in a better/faster way
  ///
  /// params :
  ///     map : type - Map, value - response object
  /// returns :
  ///     Future<String>
  static Future<String> sortJSONKeysAlphabetically(Map map) async {
    String string = "";
    try {
      string = await _hyperSnapSDKChannel.invokeMethod(
          HyperSnapSDKConstants.sortJSONKeysAlphabetically, {"map": map});
    } catch (e) {
      log(e.toString());
    }
    return string;
  }

  //---------------------------------------deprecated setters -------------------------------------
  static HyperSnapSDKConfig _hyperSnapSDKConfig = HyperSnapSDKConfig();

  @Deprecated('Use HyperSnapSDKConfig')

  /// setShouldEnableSSLPinning() is set to true if ssl pinning has to enabled in the application
  ///
  /// params :
  ///     shouldEnableSSLPinning : type - bool, value - true/false
  /// returns :
  ///     void
  static setShouldEnableSSLPinning(bool shouldEnableSSLPinning) async {
    _hyperSnapSDKConfig.shouldEnableSSLPinning = shouldEnableSSLPinning;
    await setHyperSnapSDKConfig(hyperSnapSDKConfig: _hyperSnapSDKConfig);
  }

  @Deprecated('Use HyperSnapSDKConfig')

  /// setShouldUseSignature() is set to true if signature of the images has to be used while involving api calls
  /// in the application
  ///
  /// params :
  ///     shouldUseSignature : type - bool
  /// returns :
  ///     void
  static setShouldUseSignature(bool shouldUseSignature) async {
    _hyperSnapSDKConfig.shouldUseSignature = shouldUseSignature;
    await setHyperSnapSDKConfig(hyperSnapSDKConfig: _hyperSnapSDKConfig);
  }

  @Deprecated('Use HyperSnapSDKConfig')

  /// setHttpTimeoutValues() is used to set connectionTimeout, readTimeout, writeTimeout for the api calls
  ///
  /// params :
  ///     connectTimeout : type - int
  ///     readTimeout : type - int
  ///     writeTimeout : type - int
  /// returns :
  ///     void
  static setHttpTimeoutValues(
      int connectTimeout, int readTimeout, int writeTimeout) async {
    _hyperSnapSDKConfig.timeoutConfig = HVTimeoutConfig(
        connectTimeout: connectTimeout,
        writeTimeout: writeTimeout,
        readTimeout: readTimeout);
    await setHyperSnapSDKConfig(hyperSnapSDKConfig: _hyperSnapSDKConfig);
  }

  @Deprecated('Use HyperSnapSDKConfig')

  /// setShouldReturnRawResponse() is set to true if raw response has to be returned from the plugin
  ///
  /// params :
  ///     shouldReturnRawResponse : type - bool
  /// returns :
  ///     void
  static setShouldReturnRawResponse(bool shouldReturnRawResponse) async {
    _hyperSnapSDKConfig.shouldReturnRawResponse = shouldReturnRawResponse;
    await setHyperSnapSDKConfig(hyperSnapSDKConfig: _hyperSnapSDKConfig);
  }
}

/// HyperSnapSDKConfig - used to configure the options for the sdk
class HyperSnapSDKConfig {
  bool? shouldEnableSSLPinning;
  bool? shouldUseSignature;
  bool? shouldReturnRawResponse;
  HVTimeoutConfig? timeoutConfig;

  /// HyperSnapSDKConfig() constructor used to configure the options for the sdk
  ///
  /// params :
  ///     shouldEnableSSLPinning(optional) : set to true if ssl pinning has to enabled in the application, type - bool
  ///     shouldUseSignature(optional) : set to true if signature of the images has to be used while involving api calls, type - bool
  ///     shouldReturnRawResponse(optional) : set to true if raw response has to be returned from the plugin, type - bool
  ///     timeoutConfig(optional) : used to set the timeout values

  HyperSnapSDKConfig(
      {this.shouldEnableSSLPinning,
      this.shouldReturnRawResponse,
      this.shouldUseSignature,
      this.timeoutConfig});

  /// Convert HyperSnapConfig object to Map
  Map<String, dynamic> toMap() {
    return {
      HyperSnapSDKConstants.shouldEnableSSLPinning: shouldEnableSSLPinning,
      HyperSnapSDKConstants.shouldUseSignature: shouldUseSignature,
      HyperSnapSDKConstants.shouldReturnRawResponse: shouldReturnRawResponse,
      HyperSnapSDKConstants.connectTimeout: timeoutConfig?.connectTimeout,
      HyperSnapSDKConstants.readTimeout: timeoutConfig?.readTimeout,
      HyperSnapSDKConstants.writeTimeout: timeoutConfig?.writeTimeout,
    };
  }
}

/// HVTimeoutConfig - used to configure the timeout values
class HVTimeoutConfig {
  int connectTimeout;
  int readTimeout;
  int writeTimeout;

  /// HVTimeoutConfig() constructor used to configure the timeout values
  ///
  /// params :
  ///     connectTimeout : used to set connectionTimeout for the api calls, type - int
  ///     readTimeout : used to set readTimeout for the api calls, type - int
  ///     writeTimeout : used to set writeTimeout for the api calls, type - int
  HVTimeoutConfig(
      {required this.connectTimeout,
      required this.writeTimeout,
      required this.readTimeout});
}
